@@ -30,12 +30,7 @@ def get_version(version=None):
     See https://www.python.org/dev/peps/pep-0440/
     """
 
-    version = get_full_version(version)
-    parts = 2 if version[2] == 0 else 3
-    res = '.'.join(str(x) for x in version[:parts])
-    if len(version) > 3:
-        res = "%s%s" % (res, version[3])
-    return str(res)
+    return get_full_version(version)
 
 
 def get_full_version(version=None):
